==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/PdfaType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;
import net.webpdf.wsclient.schema.ParameterInterface;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p669536_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p788398_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;When using the "Pdfa" web service, both the &lt;code&gt;&amp;lt;convert&amp;gt;&lt;/code&gt; and &lt;code&gt;&amp;lt;analyze&amp;gt;&lt;/code&gt; operations can be used.&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p669536_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p788398_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The &lt;code&gt;convert&lt;/code&gt; operation is used to convert PDF documents to PDF/A, while the &lt;code&gt;analyze&lt;/code&gt; operation is used to validate existing PDF/A documents.&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for PdfaType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="PdfaType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice>
 *         <element name="convert">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <all>
 *                   <element name="zugferd" type="{http://schema.webpdf.de/1.0/operation}ZugferdType" minOccurs="0"/>
 *                   <element name="errorCorrection" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorCorrectionType" minOccurs="0"/>
 *                 </all>
 *                 <attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" />
 *                 <attribute name="imageQuality" default="75">
 *                   <simpleType>
 *                     <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *                       <minInclusive value="0"/>
 *                       <maxInclusive value="100"/>
 *                     </restriction>
 *                   </simpleType>
 *                 </attribute>
 *                 <attribute name="errorReport" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorReportType" default="none" />
 *                 <attribute name="successReport" type="{http://schema.webpdf.de/1.0/operation}PdfaSuccessReportType" default="none" />
 *                 <attribute name="autoTagging" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *         <element name="analyze">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" />
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *       </choice>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PdfaType", propOrder = {
    "convert",
    "analyze"
})
public class PdfaType
    implements ParameterInterface
{

    protected PdfaType.Convert convert;
    protected PdfaType.Analyze analyze;

    /**
     * Gets the value of the convert property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType.Convert }
     *     
     */
    public PdfaType.Convert getConvert() {
        return convert;
    }

    /**
     * Sets the value of the convert property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType.Convert }
     *     
     */
    public void setConvert(PdfaType.Convert value) {
        this.convert = value;
    }

    public boolean isSetConvert() {
        return (this.convert!= null);
    }

    /**
     * Gets the value of the analyze property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType.Analyze }
     *     
     */
    public PdfaType.Analyze getAnalyze() {
        return analyze;
    }

    /**
     * Sets the value of the analyze property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType.Analyze }
     *     
     */
    public void setAnalyze(PdfaType.Analyze value) {
        this.analyze = value;
    }

    public boolean isSetAnalyze() {
        return (this.analyze!= null);
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" />
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Analyze {

        @XmlAttribute(name = "level")
        protected PdfaLevelType level;

        /**
         * Gets the value of the level property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaLevelType }
         *     
         */
        public PdfaLevelType getLevel() {
            if (level == null) {
                return PdfaLevelType.LEVEL_3B;
            } else {
                return level;
            }
        }

        /**
         * Sets the value of the level property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaLevelType }
         *     
         */
        public void setLevel(PdfaLevelType value) {
            this.level = value;
        }

        public boolean isSetLevel() {
            return (this.level!= null);
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <all>
     *         <element name="zugferd" type="{http://schema.webpdf.de/1.0/operation}ZugferdType" minOccurs="0"/>
     *         <element name="errorCorrection" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorCorrectionType" minOccurs="0"/>
     *       </all>
     *       <attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" />
     *       <attribute name="imageQuality" default="75">
     *         <simpleType>
     *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
     *             <minInclusive value="0"/>
     *             <maxInclusive value="100"/>
     *           </restriction>
     *         </simpleType>
     *       </attribute>
     *       <attribute name="errorReport" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorReportType" default="none" />
     *       <attribute name="successReport" type="{http://schema.webpdf.de/1.0/operation}PdfaSuccessReportType" default="none" />
     *       <attribute name="autoTagging" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {

    })
    public static class Convert {

        protected ZugferdType zugferd;
        protected PdfaErrorCorrectionType errorCorrection;
        @XmlAttribute(name = "level")
        protected PdfaLevelType level;
        @XmlAttribute(name = "imageQuality")
        protected Integer imageQuality;
        @XmlAttribute(name = "errorReport")
        protected PdfaErrorReportType errorReport;
        @XmlAttribute(name = "successReport")
        protected PdfaSuccessReportType successReport;
        @XmlAttribute(name = "autoTagging")
        protected Boolean autoTagging;

        /**
         * Gets the value of the zugferd property.
         * 
         * @return
         *     possible object is
         *     {@link ZugferdType }
         *     
         */
        public ZugferdType getZugferd() {
            return zugferd;
        }

        /**
         * Sets the value of the zugferd property.
         * 
         * @param value
         *     allowed object is
         *     {@link ZugferdType }
         *     
         */
        public void setZugferd(ZugferdType value) {
            this.zugferd = value;
        }

        public boolean isSetZugferd() {
            return (this.zugferd!= null);
        }

        /**
         * Gets the value of the errorCorrection property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaErrorCorrectionType }
         *     
         */
        public PdfaErrorCorrectionType getErrorCorrection() {
            return errorCorrection;
        }

        /**
         * Sets the value of the errorCorrection property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaErrorCorrectionType }
         *     
         */
        public void setErrorCorrection(PdfaErrorCorrectionType value) {
            this.errorCorrection = value;
        }

        public boolean isSetErrorCorrection() {
            return (this.errorCorrection!= null);
        }

        /**
         * Gets the value of the level property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaLevelType }
         *     
         */
        public PdfaLevelType getLevel() {
            if (level == null) {
                return PdfaLevelType.LEVEL_3B;
            } else {
                return level;
            }
        }

        /**
         * Sets the value of the level property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaLevelType }
         *     
         */
        public void setLevel(PdfaLevelType value) {
            this.level = value;
        }

        public boolean isSetLevel() {
            return (this.level!= null);
        }

        /**
         * Gets the value of the imageQuality property.
         * 
         * @return
         *     possible object is
         *     {@link Integer }
         *     
         */
        public int getImageQuality() {
            if (imageQuality == null) {
                return  75;
            } else {
                return imageQuality;
            }
        }

        /**
         * Sets the value of the imageQuality property.
         * 
         * @param value
         *     allowed object is
         *     {@link Integer }
         *     
         */
        public void setImageQuality(int value) {
            this.imageQuality = value;
        }

        public boolean isSetImageQuality() {
            return (this.imageQuality!= null);
        }

        public void unsetImageQuality() {
            this.imageQuality = null;
        }

        /**
         * Gets the value of the errorReport property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaErrorReportType }
         *     
         */
        public PdfaErrorReportType getErrorReport() {
            if (errorReport == null) {
                return PdfaErrorReportType.NONE;
            } else {
                return errorReport;
            }
        }

        /**
         * Sets the value of the errorReport property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaErrorReportType }
         *     
         */
        public void setErrorReport(PdfaErrorReportType value) {
            this.errorReport = value;
        }

        public boolean isSetErrorReport() {
            return (this.errorReport!= null);
        }

        /**
         * Gets the value of the successReport property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaSuccessReportType }
         *     
         */
        public PdfaSuccessReportType getSuccessReport() {
            if (successReport == null) {
                return PdfaSuccessReportType.NONE;
            } else {
                return successReport;
            }
        }

        /**
         * Sets the value of the successReport property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaSuccessReportType }
         *     
         */
        public void setSuccessReport(PdfaSuccessReportType value) {
            this.successReport = value;
        }

        public boolean isSetSuccessReport() {
            return (this.successReport!= null);
        }

        /**
         * Gets the value of the autoTagging property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isAutoTagging() {
            if (autoTagging == null) {
                return false;
            } else {
                return autoTagging;
            }
        }

        /**
         * Sets the value of the autoTagging property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setAutoTagging(boolean value) {
            this.autoTagging = value;
        }

        public boolean isSetAutoTagging() {
            return (this.autoTagging!= null);
        }

        public void unsetAutoTagging() {
            this.autoTagging = null;
        }

    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/PdfaType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;
import net.webpdf.wsclient.schema.ParameterInterface;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p120962_="https://jakarta.ee/xml/ns/jaxb" xmlns:p964117_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;When using the "Pdfa" web service, both the &lt;code&gt;&amp;lt;convert&amp;gt;&lt;/code&gt; and &lt;code&gt;&amp;lt;analyze&amp;gt;&lt;/code&gt; operations can be used.&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p120962_="https://jakarta.ee/xml/ns/jaxb" xmlns:p964117_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The &lt;code&gt;convert&lt;/code&gt; operation is used to convert PDF documents to PDF/A, while the &lt;code&gt;analyze&lt;/code&gt; operation is used to validate existing PDF/A documents.&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for PdfaType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="PdfaType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice>
 *         <element name="convert">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <all>
 *                   <element name="zugferd" type="{http://schema.webpdf.de/1.0/operation}ZugferdType" minOccurs="0"/>
 *                   <element name="errorCorrection" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorCorrectionType" minOccurs="0"/>
 *                 </all>
 *                 <attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" />
 *                 <attribute name="imageQuality" default="75">
 *                   <simpleType>
 *                     <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *                       <minInclusive value="0"/>
 *                       <maxInclusive value="100"/>
 *                     </restriction>
 *                   </simpleType>
 *                 </attribute>
 *                 <attribute name="errorReport" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorReportType" default="none" />
 *                 <attribute name="successReport" type="{http://schema.webpdf.de/1.0/operation}PdfaSuccessReportType" default="none" />
 *                 <attribute name="autoTagging" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *         <element name="analyze">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" />
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *       </choice>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PdfaType", propOrder = {
    "convert",
    "analyze"
})
public class PdfaType
    implements ParameterInterface
{

    protected PdfaType.Convert convert;
    protected PdfaType.Analyze analyze;

    /**
     * Gets the value of the convert property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType.Convert }
     *     
     */
    public PdfaType.Convert getConvert() {
        return convert;
    }

    /**
     * Sets the value of the convert property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType.Convert }
     *     
     */
    public void setConvert(PdfaType.Convert value) {
        this.convert = value;
    }

    public boolean isSetConvert() {
        return (this.convert!= null);
    }

    /**
     * Gets the value of the analyze property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType.Analyze }
     *     
     */
    public PdfaType.Analyze getAnalyze() {
        return analyze;
    }

    /**
     * Sets the value of the analyze property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType.Analyze }
     *     
     */
    public void setAnalyze(PdfaType.Analyze value) {
        this.analyze = value;
    }

    public boolean isSetAnalyze() {
        return (this.analyze!= null);
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" />
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Analyze {

        @XmlAttribute(name = "level")
        protected PdfaLevelType level;

        /**
         * Gets the value of the level property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaLevelType }
         *     
         */
        public PdfaLevelType getLevel() {
            if (level == null) {
                return PdfaLevelType.LEVEL_3B;
            } else {
                return level;
            }
        }

        /**
         * Sets the value of the level property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaLevelType }
         *     
         */
        public void setLevel(PdfaLevelType value) {
            this.level = value;
        }

        public boolean isSetLevel() {
            return (this.level!= null);
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <all>
     *         <element name="zugferd" type="{http://schema.webpdf.de/1.0/operation}ZugferdType" minOccurs="0"/>
     *         <element name="errorCorrection" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorCorrectionType" minOccurs="0"/>
     *       </all>
     *       <attribute name="level" type="{http://schema.webpdf.de/1.0/operation}PdfaLevelType" default="3b" />
     *       <attribute name="imageQuality" default="75">
     *         <simpleType>
     *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
     *             <minInclusive value="0"/>
     *             <maxInclusive value="100"/>
     *           </restriction>
     *         </simpleType>
     *       </attribute>
     *       <attribute name="errorReport" type="{http://schema.webpdf.de/1.0/operation}PdfaErrorReportType" default="none" />
     *       <attribute name="successReport" type="{http://schema.webpdf.de/1.0/operation}PdfaSuccessReportType" default="none" />
     *       <attribute name="autoTagging" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {

    })
    public static class Convert {

        protected ZugferdType zugferd;
        protected PdfaErrorCorrectionType errorCorrection;
        @XmlAttribute(name = "level")
        protected PdfaLevelType level;
        @XmlAttribute(name = "imageQuality")
        protected Integer imageQuality;
        @XmlAttribute(name = "errorReport")
        protected PdfaErrorReportType errorReport;
        @XmlAttribute(name = "successReport")
        protected PdfaSuccessReportType successReport;
        @XmlAttribute(name = "autoTagging")
        protected Boolean autoTagging;

        /**
         * Gets the value of the zugferd property.
         * 
         * @return
         *     possible object is
         *     {@link ZugferdType }
         *     
         */
        public ZugferdType getZugferd() {
            return zugferd;
        }

        /**
         * Sets the value of the zugferd property.
         * 
         * @param value
         *     allowed object is
         *     {@link ZugferdType }
         *     
         */
        public void setZugferd(ZugferdType value) {
            this.zugferd = value;
        }

        public boolean isSetZugferd() {
            return (this.zugferd!= null);
        }

        /**
         * Gets the value of the errorCorrection property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaErrorCorrectionType }
         *     
         */
        public PdfaErrorCorrectionType getErrorCorrection() {
            return errorCorrection;
        }

        /**
         * Sets the value of the errorCorrection property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaErrorCorrectionType }
         *     
         */
        public void setErrorCorrection(PdfaErrorCorrectionType value) {
            this.errorCorrection = value;
        }

        public boolean isSetErrorCorrection() {
            return (this.errorCorrection!= null);
        }

        /**
         * Gets the value of the level property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaLevelType }
         *     
         */
        public PdfaLevelType getLevel() {
            if (level == null) {
                return PdfaLevelType.LEVEL_3B;
            } else {
                return level;
            }
        }

        /**
         * Sets the value of the level property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaLevelType }
         *     
         */
        public void setLevel(PdfaLevelType value) {
            this.level = value;
        }

        public boolean isSetLevel() {
            return (this.level!= null);
        }

        /**
         * Gets the value of the imageQuality property.
         * 
         * @return
         *     possible object is
         *     {@link Integer }
         *     
         */
        public int getImageQuality() {
            if (imageQuality == null) {
                return  75;
            } else {
                return imageQuality;
            }
        }

        /**
         * Sets the value of the imageQuality property.
         * 
         * @param value
         *     allowed object is
         *     {@link Integer }
         *     
         */
        public void setImageQuality(int value) {
            this.imageQuality = value;
        }

        public boolean isSetImageQuality() {
            return (this.imageQuality!= null);
        }

        public void unsetImageQuality() {
            this.imageQuality = null;
        }

        /**
         * Gets the value of the errorReport property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaErrorReportType }
         *     
         */
        public PdfaErrorReportType getErrorReport() {
            if (errorReport == null) {
                return PdfaErrorReportType.NONE;
            } else {
                return errorReport;
            }
        }

        /**
         * Sets the value of the errorReport property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaErrorReportType }
         *     
         */
        public void setErrorReport(PdfaErrorReportType value) {
            this.errorReport = value;
        }

        public boolean isSetErrorReport() {
            return (this.errorReport!= null);
        }

        /**
         * Gets the value of the successReport property.
         * 
         * @return
         *     possible object is
         *     {@link PdfaSuccessReportType }
         *     
         */
        public PdfaSuccessReportType getSuccessReport() {
            if (successReport == null) {
                return PdfaSuccessReportType.NONE;
            } else {
                return successReport;
            }
        }

        /**
         * Sets the value of the successReport property.
         * 
         * @param value
         *     allowed object is
         *     {@link PdfaSuccessReportType }
         *     
         */
        public void setSuccessReport(PdfaSuccessReportType value) {
            this.successReport = value;
        }

        public boolean isSetSuccessReport() {
            return (this.successReport!= null);
        }

        /**
         * Gets the value of the autoTagging property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isAutoTagging() {
            if (autoTagging == null) {
                return false;
            } else {
                return autoTagging;
            }
        }

        /**
         * Sets the value of the autoTagging property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setAutoTagging(boolean value) {
            this.autoTagging = value;
        }

        public boolean isSetAutoTagging() {
            return (this.autoTagging!= null);
        }

        public void unsetAutoTagging() {
            this.autoTagging = null;
        }

    }

}
